// <copyright file="SyncfusionVirtualGrid.cs" company="ANUJ Technologies Inc.">
// Copyright (c) 11-13-2011 All Right Reserved
// </copyright>
// <author>Anuj Varma, www.anujvarma.com</author>
// <date>11-13-2011</date>
// <summary>Class representing a SyncfusionVirtualGrid.cs entity.</summary>

using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Data;
using VirtualGrids.DomainObjects;

namespace VirtualGrids
{
	/// <summary>
	/// Summary description for Form1.
	/// </summary>
	public class SyncfusionVirtualGrid : System.Windows.Forms.Form
	{
        DateTime startRefreshTime;
		//public ArrayList _addressData = new ArrayList();
		private Syncfusion.Windows.Forms.Grid.GridControl gridControl1;
		/// <summary>
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;
        private Button button1;
        private Label label1;
        private System.Collections.ArrayList _customers =  new System.Collections.ArrayList();
        
        public SyncfusionVirtualGrid()
		{
            InitializeComponent();
            InitializeData();
            InitializeGrid();
            gridControl1.RefreshRequest += new EventHandler(refreshHandler);

            startRefreshTime = DateTime.Now;
            gridControl1.Refresh();            
            TimeSpan duration = DateTime.Now - startRefreshTime;
            label1.Text = "Total Refresh Time = " + duration.TotalMilliseconds + " milliseconds";    
		}

        void refreshHandler(object sender, EventArgs args)
        {
            startRefreshTime = DateTime.Now;			
        }

		void InitializeGrid()
		{
			// set up header
			gridControl1[0, 1].CellValue  = "Company Name";
			gridControl1[0, 2].CellValue  = "Contact Name";

			// set up styles
			gridControl1.ColStyles[1].BackColor = Color.LightBlue;
			gridControl1.ColStyles[5].TextColor = Color.Red;
			gridControl1.ColStyles[7].Font.Bold = true;
			gridControl1.ColWidths[7] = (int)this.Font.Size * 20;
		}

		void InitializeData()
		{
			AddCustomerData();
		}


		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if (components != null) 
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
            this.gridControl1 = new Syncfusion.Windows.Forms.Grid.GridControl();
            this.button1 = new System.Windows.Forms.Button();
            this.label1 = new System.Windows.Forms.Label();
            ((System.ComponentModel.ISupportInitialize)(this.gridControl1)).BeginInit();
            this.SuspendLayout();
            // 
            // gridControl1
            // 
            this.gridControl1.Location = new System.Drawing.Point(64, 24);
            this.gridControl1.Name = "gridControl1";
            this.gridControl1.Size = new System.Drawing.Size(528, 217);
            this.gridControl1.SmartSizeBox = false;
            this.gridControl1.TabIndex = 0;
            this.gridControl1.Text = "gridControl1";
            this.gridControl1.QueryColCount += new Syncfusion.Windows.Forms.Grid.GridRowColCountEventHandler(this.gridControl1_QueryColCount);
            this.gridControl1.CellClick += new Syncfusion.Windows.Forms.Grid.GridCellClickEventHandler(this.gridControl1_CellClick);
            this.gridControl1.QueryCellInfo += new Syncfusion.Windows.Forms.Grid.GridQueryCellInfoEventHandler(this.gridControl1_QueryCellInfo);
            this.gridControl1.QueryRowCount += new Syncfusion.Windows.Forms.Grid.GridRowColCountEventHandler(this.gridControl1_QueryRowCount);
            // 
            // button1
            // 
            this.button1.Location = new System.Drawing.Point(64, 258);
            this.button1.Name = "button1";
            this.button1.Size = new System.Drawing.Size(94, 23);
            this.button1.TabIndex = 1;
            this.button1.Text = "Export to Excel";
            this.button1.UseVisualStyleBackColor = true;
            this.button1.Click += new System.EventHandler(this.button1_Click);
            // 
            // label1
            // 
            this.label1.AutoSize = true;
            this.label1.Location = new System.Drawing.Point(360, 280);
            this.label1.Name = "label1";
            this.label1.Size = new System.Drawing.Size(35, 13);
            this.label1.TabIndex = 2;
            this.label1.Text = "label1";
            // 
            // SyncfusionVirtualGrid
            // 
            this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
            this.ClientSize = new System.Drawing.Size(640, 330);
            this.Controls.Add(this.label1);
            this.Controls.Add(this.button1);
            this.Controls.Add(this.gridControl1);
            this.Name = "SyncfusionVirtualGrid";
            this.Text = "SyncFusion Virtual Grid Sample";
            ((System.ComponentModel.ISupportInitialize)(this.gridControl1)).EndInit();
            this.ResumeLayout(false);
            this.PerformLayout();

		}
		#endregion

		/// <summary>
		/// QueryCellInfo and QueryRowCount are the two main eventHandlers needed to make the virtual mode work for the Syncfusion grid.
        /// Fill the cell with data upon request from the grid
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		private void gridControl1_QueryCellInfo(object sender, Syncfusion.Windows.Forms.Grid.GridQueryCellInfoEventArgs e)
		{
			if (e.RowIndex > 0 && e.ColIndex > 0)
			{
			  if(e.ColIndex == 1)
                  e.Style.CellValue = ((Customer)_customers[e.RowIndex-1]).CompanyName;
			  else if(e.ColIndex == 2)
                  e.Style.CellValue = ((Customer)_customers[e.RowIndex - 1]).ContactName;

                e.Handled = true;
			}
		}

        /// <summary>
        /// QueryCellInfo and QueryRowCount are the two main eventHandlers needed to make the virtual mode work for the Syncfusion grid.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void gridControl1_QueryRowCount(object sender, Syncfusion.Windows.Forms.Grid.GridRowColCountEventArgs e)
		{
			e.Count =  _customers.Count;
			e.Handled = true;
		}

		private void gridControl1_CellClick(object sender, Syncfusion.Windows.Forms.Grid.GridCellClickEventArgs e)
		{
			// if clicked in header, sort
			if ((e.RowIndex == 0) && (e.ColIndex > 0))
			{
                Customer.CompareIndex = e.ColIndex - 1;
				_customers.Sort();
				gridControl1.Refresh();
			}
		}

		private void gridControl1_QueryColCount(object sender, Syncfusion.Windows.Forms.Grid.GridRowColCountEventArgs e)
		{
			e.Count =  2;
			e.Handled = true;
		}
        	
        private void AddCustomerData()
        {
            for (int i = 0; i < Constants.numRows; i++)
            {
                string company = "ABC" + i + " Corp";
                string name = "A" + i + "V" + i;
                Customer c = new Customer(company, name);
                this._customers.Add(c);
            }

            // Set the row count, including the row for new records.
             this.gridControl1.RowCount = Constants.numRows;
        }

        private void button1_Click(object sender, EventArgs e)
        {
            // Export to excel
            Syncfusion.GridExcelConverter.GridExcelConverterControl gecc = new Syncfusion.GridExcelConverter.GridExcelConverterControl();
            gecc.GridToExcel(this.gridControl1.Model, @"C:\MyGC.xls");
        }
	}
}
